@@ -1,5 +1,3 @@
-
-
 '''
 .. module:: skrf.plotting
 ========================================
@@ -19,15 +17,15 @@ Plots and Charts
     plot_smith
     plot_rectangular
     plot_polar
-    plot_complex_rectangular 
+    plot_complex_rectangular
     plot_complex_polar
-    
+
 Misc Functions
 -----------------
 
 .. autosummary::
     :toctree: generated/
-    
+
     save_all_figs
     add_markers_to_lines
     legend_off
@@ -38,6 +36,7 @@ Misc Functions
 import os
 
 import matplotlib as mpl
+from matplotlib import ticker
 import matplotlib.pyplot as plb
 import numpy as npy
 from matplotlib.patches import Circle   # for drawing smith chart
@@ -51,6 +50,21 @@ from . util import now_string_2_dt
 
 #from matplotlib.lines import Line2D            # for drawing smith chart
 
+SI_PREFIXES_ASCII = 'yzafpnum kMGTPEZY'
+SI_CONVERSION = dict([(key, 10**((8-i)*3)) for i, key in enumerate(SI_PREFIXES_ASCII)])
+
+
+def scale_frequency_ticks(ax, funit):
+    if funit.lower() == "hz":
+        prefix = " "
+        scale = 1
+    elif len(funit) == 3:
+        prefix = funit[0]
+        scale = SI_CONVERSION[prefix]
+    else:
+        raise ValueError("invalid funit {}".format(funit))
+    ticks_x = ticker.FuncFormatter(lambda x, pos: '{0:g}'.format(x * scale))
+    ax.xaxis.set_major_formatter(ticks_x)
 
 
 def smith(smithR=1, chart_type = 'z', draw_labels = False, border=False,
@@ -69,15 +83,15 @@ def smith(smithR=1, chart_type = 'z', draw_labels = False, border=False,
              * *'zy'* : lines of constant impedance stronger than admittance
              * *'yz'* : lines of constant admittance stronger than impedance
     draw_labels : Boolean
-             annotate real and imaginary parts of impedance on the 
+             annotate real and imaginary parts of impedance on the
              chart (only if smithR=1)
     border : Boolean
-        draw a rectangular border with axis ticks, around the perimeter 
+        draw a rectangular border with axis ticks, around the perimeter
         of the figure. Not used if draw_labels = True
-    
+
     ax : matplotlib.axes object
             existing axes to draw smith chart on
-    
+
     ref_imm : number
             Reference immittance for center of Smith chart. Only changes
             labels, if printed.
@@ -179,15 +193,15 @@ def smith(smithR=1, chart_type = 'z', draw_labels = False, border=False,
     # Set axis limits by plotting white points so zooming works properly
     ax1.plot(smithR*npy.array([-1.1, 1.1]), smithR*npy.array([-1.1, 1.1]), 'w.', markersize = 0)
     ax1.axis('image') # Combination of 'equal' and 'tight'
-    
-    
-    if not border: 
+
+
+    if not border:
         ax1.yaxis.set_ticks([])
         ax1.xaxis.set_ticks([])
         for loc, spine in ax1.spines.items():
             spine.set_color('none')
-        
-    
+
+
     if draw_labels:
         #Clear axis
         ax1.yaxis.set_ticks([])
@@ -224,7 +238,7 @@ def smith(smithR=1, chart_type = 'z', draw_labels = False, border=False,
                 S *= smithR * radialScaleFactor
                 rhox = S.real
                 rhoy = S.imag * y_flip_sign
-                
+
                 # Choose alignment anchor point based on label's value
                 if ((value == 1.0) or (value == -1.0)):
                     halignstyle = "center"
@@ -232,7 +246,7 @@ def smith(smithR=1, chart_type = 'z', draw_labels = False, border=False,
                     halignstyle = "right"
                 else:
                     halignstyle = "left"
-                
+
                 if (rhoy < 0):
                     valignstyle = "top"
                 else:
@@ -260,14 +274,17 @@ def smith(smithR=1, chart_type = 'z', draw_labels = False, border=False,
         cc=ax1.add_patch(currentContour)
         cc.set_clip_path(clipc)
 
+
 def plot_rectangular(x, y, x_label=None, y_label=None, title=None,
-    show_legend=True, axis='tight', ax=None, *args, **kwargs):
+                     show_legend=True, axis='tight', ax=None, *args, **kwargs):
     '''
     plots rectangular data and optionally label axes.
 
     Parameters
     ------------
-    z : array-like, of complex data
+    x : array-like, of complex data
+        data to plot
+    y : array-like, of complex data
         data to plot
     x_label : string
         x-axis label
@@ -277,10 +294,12 @@ def plot_rectangular(x, y, x_label=None, y_label=None, title=None,
         plot title
     show_legend : Boolean
         controls the drawing of the legend
+    axis : str
+        whether or not to autoscale the axis
     ax : :class:`matplotlib.axes.AxesSubplot` object
         axes to draw on
-    *args,**kwargs : passed to pylab.plot
-    
+    *args, **kwargs : passed to pylab.plot
+
     '''
     if ax is None:
         ax = plb.gca()
@@ -304,12 +323,13 @@ def plot_rectangular(x, y, x_label=None, y_label=None, title=None,
     if axis is not None:
         ax.autoscale(True, 'x', True)
         ax.autoscale(True, 'y', False)
-        
+
     if plb.isinteractive():
         plb.draw()
-    
+
     return my_plot
 
+
 def plot_polar(theta, r, x_label=None, y_label=None, title=None,
     show_legend=True, axis_equal=False, ax=None, *args, **kwargs):
     '''
@@ -320,7 +340,7 @@ def plot_polar(theta, r, x_label=None, y_label=None, title=None,
     theta : array-like
         data to plot
     r : array-like
-        
+
     x_label : string
         x-axis label
     y_label : string
@@ -332,7 +352,7 @@ def plot_polar(theta, r, x_label=None, y_label=None, title=None,
     ax : :class:`matplotlib.axes.AxesSubplot` object
         axes to draw on
     *args,**kwargs : passed to pylab.plot
-    
+
     See Also
     ----------
     plot_rectangular : plots rectangular data
@@ -363,7 +383,7 @@ def plot_polar(theta, r, x_label=None, y_label=None, title=None,
 
     if axis_equal:
         ax.axis('equal')
-        
+
     if plb.isinteractive():
         plb.draw()
 
@@ -396,7 +416,7 @@ def plot_complex_rectangular(z, x_label='Real', y_label='Imag',
     plot_polar : plot polar data
     plot_complex_polar : plot complex data on polar plane
     plot_smith : plot complex data on smith chart
-    
+
     '''
     x = npy.real(z)
     y = npy.imag(z)
@@ -404,6 +424,7 @@ def plot_complex_rectangular(z, x_label='Real', y_label='Imag',
         title=title, show_legend=show_legend, axis=axis,
         ax=ax, *args, **kwargs)
 
+
 def plot_complex_polar(z, x_label=None, y_label=None,
     title=None, show_legend=True, axis_equal=False, ax=None,
     *args, **kwargs):
@@ -440,6 +461,7 @@ def plot_complex_polar(z, x_label=None, y_label=None,
         title=title, show_legend=show_legend, axis_equal=axis_equal,
         ax=ax, *args, **kwargs)
 
+
 def plot_smith(s, smith_r=1, chart_type='z', x_label='Real',
     y_label='Imaginary', title='Complex Plane', show_legend=True,
     axis='equal', ax=None, force_chart = False, draw_vswr=None, *args, **kwargs):
@@ -467,7 +489,7 @@ def plot_smith(s, smith_r=1, chart_type='z', x_label='Real',
     axis_equal: Boolean
         sets axis to be equal increments (calls axis('equal'))
     force_chart : Boolean
-        forces the re-drawing of smith chart 
+        forces the re-drawing of smith chart
     ax : :class:`matplotlib.axes.AxesSubplot` object
         axes to draw on
     *args,**kwargs : passed to pylab.plot
@@ -480,7 +502,7 @@ def plot_smith(s, smith_r=1, chart_type='z', x_label='Real',
     plot_complex_polar : plot complex data on polar plane
     plot_smith : plot complex data on smith chart
     '''
-    
+
     if ax is None:
         ax = plb.gca()
 
@@ -498,15 +520,15 @@ def plot_smith(s, smith_r=1, chart_type='z', x_label='Real',
         plb.draw()
 
 
-def subplot_params(ntwk, param='s', proj='db', size_per_port=4, newfig=True,  
+def subplot_params(ntwk, param='s', proj='db', size_per_port=4, newfig=True,
                    add_titles=True, keep_it_tight=True,  subplot_kw={}, *args, **kw):
     '''
     Plot all networks parameters individually on subplots
-    
+
     Parameters
     --------------
-    
-    
+
+
     '''
     if newfig:
         f,axs= plb.subplots(ntwk.nports,ntwk.nports,
@@ -514,7 +536,7 @@ def subplot_params(ntwk, param='s', proj='db', size_per_port=4, newfig=True,
                                       size_per_port*ntwk.nports ),
                                       **subplot_kw)
     else:
-        f = plb.gcf() 
+        f = plb.gcf()
         axs = npy.array(f.get_axes())
 
     for ports,ax in zip(ntwk.port_tuples, axs.flatten()):
@@ -529,23 +551,23 @@ def subplot_params(ntwk, param='s', proj='db', size_per_port=4, newfig=True,
 def shade_bands(edges, y_range=None,cmap='prism', **kwargs):
     '''
     Shades frequency bands.
-    
-    when plotting data over a set of frequency bands it is nice to 
+
+    when plotting data over a set of frequency bands it is nice to
     have each band visually separated from the other. The kwarg `alpha`
     is useful.
-    
-    Parameters 
+
+    Parameters
     --------------
     edges : array-like
         x-values separating regions of a given shade
-    y_range : tuple 
-        y-values to shade in 
+    y_range : tuple
+        y-values to shade in
     cmap : str
         see matplotlib.cm  or matplotlib.colormaps for acceptable values
     \*\* : key word arguments
         passed to `matplotlib.fill_between`
-        
-    Examples 
+
+    Examples
     -----------
     >>> rf.shade_bands([325,500,750,1100], alpha=.2)
     '''
@@ -554,8 +576,8 @@ def shade_bands(edges, y_range=None,cmap='prism', **kwargs):
     axis = plb.axis()
     for k in range(len(edges)-1):
         plb.fill_between(
-            [edges[k],edges[k+1]], 
-            y_range[0], y_range[1], 
+            [edges[k],edges[k+1]],
+            y_range[0], y_range[1],
             color = cmap(1.0*k/len(edges)),
             **kwargs)
     plb.axis(axis)
@@ -596,13 +618,13 @@ saf = save_all_figs
 
 def add_markers_to_lines(ax=None,marker_list=['o','D','s','+','x'], markevery=10):
     '''
-    adds markers to existing lings on a plot 
-    
-    this is convinient if you have already have a plot made, but then 
-    need to add markers afterwards, so that it can be interpreted in 
-    black and white. The markevery argument makes the markers less 
-    frequent than the data, which is generally what you want. 
-    
+    adds markers to existing lings on a plot
+
+    this is convinient if you have already have a plot made, but then
+    need to add markers afterwards, so that it can be interpreted in
+    black and white. The markevery argument makes the markers less
+    frequent than the data, which is generally what you want.
+
     Parameters
     -----------
     ax : matplotlib.Axes
@@ -611,7 +633,7 @@ def add_markers_to_lines(ax=None,marker_list=['o','D','s','+','x'], markevery=10
         see matplotlib.plot help for possible marker characters
     markevery : int
         markevery number of points with a marker.
-    
+
     '''
     if ax is None:
         ax=plb.gca()
@@ -623,14 +645,14 @@ def add_markers_to_lines(ax=None,marker_list=['o','D','s','+','x'], markevery=10
 
 def legend_off(ax=None):
     '''
-    turn off the legend for a given axes. 
-    
+    turn off the legend for a given axes.
+
     if no axes is given then it will use current axes.
-    
+
     Parameters
     -----------
     ax : matplotlib.Axes object
-        axes to operate on 
+        axes to operate on
     '''
     if ax is None:
         plb.gca().legend_.set_visible(0)
@@ -640,41 +662,41 @@ def legend_off(ax=None):
 def scrape_legend(n=None, ax=None):
     '''
     scrapes a legend with redundant labels
-    
-    Given a legend of m entries of n groups, this will remove all but 
+
+    Given a legend of m entries of n groups, this will remove all but
     every m/nth entry. This is used when you plot many lines representing
     the same thing, and only want one label entry in the legend  for the
     whole ensemble of lines
-    
+
     '''
-    
+
     if ax is None:
         ax = plb.gca()
-    
+
     handles, labels = ax.get_legend_handles_labels()
-    
+
     if n is None:
         n =len ( set(labels))
-    
+
     if n>len(handles):
         raise ValueError('number of entries is too large')
-    
+
     k_list = [int(k) for k in npy.linspace(0,len(handles)-1,n)]
     ax.legend([handles[k] for k in k_list], [labels[k] for k in k_list])
 
 def func_on_all_figs(func, *args, **kwargs):
     '''
-    runs a function after making all open figures current. 
-    
-    useful if you need to change the properties of many open figures 
-    at once, like turn off the grid. 
-    
+    runs a function after making all open figures current.
+
+    useful if you need to change the properties of many open figures
+    at once, like turn off the grid.
+
     Parameters
     ----------
     func : function
         function to call
     \*args, \*\*kwargs : pased to func
-    
+
     Examples
     ----------
     >>> rf.func_on_all_figs(grid,alpha=.3)
@@ -690,14 +712,14 @@ foaf = func_on_all_figs
 
 def plot_vector(a, off=0+0j, *args, **kwargs):
     '''
-    plot a 2d vector 
+    plot a 2d vector
     '''
-    return quiver(off.real,off.imag,a.real,a.imag,scale_units ='xy', 
+    return quiver(off.real,off.imag,a.real,a.imag,scale_units ='xy',
            angles='xy',scale=1, *args, **kwargs)
 
 
 def colors():
-    return rcParams['axes.color_cycle']
+    return [c['color'] for c in rcParams['axes.prop_cycle']]
 
 
 PRIMARY_PROPERTIES = network.PRIMARY_PROPERTIES
@@ -743,8 +765,8 @@ def __generate_plot_functions(self):
     for prop_name in PRIMARY_PROPERTIES:
 
         def plot_prop_polar(self,
-            m=None, n=None, ax=None,
-            show_legend=True ,prop_name=prop_name,*args, **kwargs):
+                            m=None, n=None, ax=None,
+                            show_legend=True, prop_name=prop_name, *args, **kwargs):
 
             # create index lists, if not provided by user
             if m is None:
@@ -761,10 +783,9 @@ def __generate_plot_functions(self):
             else:
                 gen_label = False
 
-
-            was_interactive = plb.isinteractive
-            if was_interactive:
-                plb.interactive(False)
+            # was_interactive = plb.isinteractive
+            # if was_interactive:
+            #     plb.interactive(False)
 
             for m in M:
                 for n in N:
@@ -794,10 +815,10 @@ def __generate_plot_functions(self):
                          show_legend = show_legend, ax = ax,
                         *args, **kwargs)
 
-            if was_interactive:
-                plb.interactive(True)
-                plb.draw()
-                plb.show()
+            # if was_interactive:
+            #     plb.interactive(True)
+            #     plb.draw()
+            #     plb.show()
 
         plot_prop_polar.__doc__ = '''
 plot the Network attribute :attr:`%s` vs frequency.
@@ -829,14 +850,13 @@ initialization. This is accomplished by calling
 Examples
 ------------
 >>> myntwk.plot_%s(m=1,n=0,color='r')
-'''%(prop_name,prop_name)
+''' % (prop_name, prop_name)
         # setattr(self.__class__,'plot_%s_polar'%(prop_name), \
-        setattr(self,'plot_%s_polar'%(prop_name), \
-            plot_prop_polar)
+        setattr(self, 'plot_%s_polar'%(prop_name), plot_prop_polar)
 
         def plot_prop_rect(self,
-            m=None, n=None, ax=None,
-            show_legend=True,prop_name=prop_name,*args, **kwargs):
+                           m=None, n=None, ax=None,
+                           show_legend=True, prop_name=prop_name, *args, **kwargs):
 
             # create index lists, if not provided by user
             if m is None:
@@ -853,7 +873,6 @@ Examples
             else:
                 gen_label = False
 
-
             #was_interactive = plb.isinteractive
             #if was_interactive:
             #    plb.interactive(False)
@@ -882,8 +901,8 @@ Examples
 
                     # plot the desired attribute vs frequency
                     plot_complex_rectangular(
-                        z = getattr(self,prop_name)[:,m,n],
-                         show_legend = show_legend, ax = ax,
+                        z=getattr(self, prop_name)[:, m, n],
+                        show_legend=show_legend, ax=ax,
                         *args, **kwargs)
 
             #if was_interactive:
@@ -921,7 +940,7 @@ initialization. This is accomplished by calling
 Examples
 ------------
 >>> myntwk.plot_%s(m=1,n=0,color='r')
-'''%(prop_name,prop_name)
+''' % (prop_name, prop_name)
 
         # setattr(self.__class__,'plot_%s_complex'%(prop_name), \
         setattr(self,'plot_%s_complex'%(prop_name), \
@@ -929,12 +948,12 @@ Examples
 
 
         for func_name in COMPONENT_FUNC_DICT:
-            attribute = '%s_%s'%(prop_name, func_name)
+            attribute = '%s_%s' % (prop_name, func_name)
             y_label = Y_LABEL_DICT[func_name]
 
             def plot_func(self,  m=None, n=None, ax=None,
-                show_legend=True,attribute=attribute,
-                y_label=y_label,*args, **kwargs):
+                          show_legend=True, attribute=attribute,
+                          y_label=y_label, pad=0, window='hamming', z0=50, *args, **kwargs):
 
                 # create index lists, if not provided by user
                 if m is None:
@@ -955,10 +974,9 @@ Examples
                 # this didnt work because it required a show()
                 # to be called, which in turn, disrupted testCases
                 #
-                #was_interactive = plb.isinteractive
-                #if was_interactive:
-                #    plb.interactive(False)
-
+                # was_interactive = plb.isinteractive
+                # if was_interactive:
+                #     plb.interactive(False)
                 for m in M:
                     for n in N:
                         # set the legend label for this trace to the networks
@@ -981,24 +999,62 @@ Examples
                                     (attribute[0].upper(),m+1,n+1)
                             kwargs['label'] = label_string
 
-                        # plot the desired attribute vs frequency
-                        if 'time' in attribute:
+                        # quick and dirty way to plot step and impulse response
+                        if 'time_impulse' in attribute:
                             xlabel = 'Time (ns)'
-                            x = self.frequency.t_ns
-
+                            x,y = self.impulse_response(pad=pad, window=window)
+                            # default is reflexion coefficient axis
+                            if attribute[0].lower() == 'z':
+                                # if they want impedance axis, give it to them
+                                y_label = 'Z (ohm)'
+                                y[x ==  1.] =  1. + 1e-12  # solve numerical singularity
+                                y[x == -1.] = -1. + 1e-12  # solve numerical singularity
+                                y = z0 * (1+y) / (1-y)
+                            plot_rectangular(x=x,
+                                             y=y,
+                                             x_label=xlabel,
+                                             y_label=y_label,
+                                             show_legend=show_legend, ax=ax,
+                                             *args, **kwargs)
+                        elif 'time_step' in attribute:
+                            xlabel = 'Time (ns)'
+                            x, y = self.step_response(pad=pad, window=window)
+                            # default is reflexion coefficient axis
+                            if attribute[0].lower() == 'z':
+                                # if they want impedance axis, give it to them
+                                y_label = 'Z (ohm)'
+                                y[x ==  1.] =  1. + 1e-12  # solve numerical singularity
+                                y[x == -1.] = -1. + 1e-12  # solve numerical singularity
+                                y = z0 * (1+y) / (1-y)
+                            plot_rectangular(x=x,
+                                             y=y,
+                                             x_label=xlabel,
+                                             y_label=y_label,
+                                             show_legend=show_legend, ax=ax,
+                                             *args, **kwargs)
+                            
                         else:
-                            xlabel = 'Frequency (%s)'%self.frequency.unit
-                            x = self.frequency.f_scaled
-
-                        plot_rectangular(
-                                x = x,
-                                y = getattr(self,attribute)[:,m,n],
-                                x_label = xlabel,
-                                y_label = y_label,
-                                show_legend = show_legend, ax = ax,
-                                *args, **kwargs)
+                            # plot the desired attribute vs frequency
+                            if 'time' in attribute:
+                                xlabel = 'Time (ns)'
+                                x = self.frequency.t_ns
+    
+                            else:
+                                xlabel = 'Frequency (%s)' % self.frequency.unit
+                                # x = self.frequency.f_scaled
+                                x = self.frequency.f  # always plot f, and then scale the ticks instead
 
+                                # scale the ticklabels according to the frequency unit:
+                                if ax is None:
+                                    ax = plb.gca()
+                                scale_frequency_ticks(ax, self.frequency.unit)
 
+                            plot_rectangular(x=x,
+                                             y=getattr(self, attribute)[:, m, n],
+                                             x_label=xlabel,
+                                             y_label=y_label,
+                                             show_legend=show_legend, ax=ax,
+                                             *args, **kwargs)
                 #if was_interactive:
                 #    plb.interactive(True)
                 #    plb.draw()
@@ -1065,7 +1121,6 @@ def plot_v_frequency(self, y, *args, **kwargs):
 
     This plots whatever is given vs. `self.f_scaled` and then
     calls `labelXAxis`.
-
     '''
 
     try:
@@ -1087,7 +1142,10 @@ def plot_v_frequency(self, y, *args, **kwargs):
     except(TypeError):
         y = y * npy.ones(len(self))
 
-    plb.plot(self.f_scaled, y, *args, **kwargs)
+    # plb.plot(self.f_scaled, y, *args, **kwargs)
+    plb.plot(self.f, y, *args, **kwargs)
+    ax = plb.gca()
+    scale_frequency_ticks(ax, self.unit)
     plb.autoscale(axis='x', tight=True)
     self.labelXAxis()
 
@@ -1487,9 +1545,11 @@ def animate(self, attr='s_deg', ylims=(-5, 5), xlims=None, show=True,
     if was_interactive:
         plb.ion()
 
-def plot_uncertainty_bounds_component(self,attribute,m=None,n=None,\
-        type='shade',n_deviations=3, alpha=.3, color_error =None,markevery_error=20,
-        ax=None,ppf=None,kwargs_error={},*args,**kwargs):
+
+def plot_uncertainty_bounds_component(
+        self, attribute, m=None, n=None,
+        type='shade', n_deviations=3, alpha=.3, color_error=None, markevery_error=20,
+        ax=None, ppf=None, kwargs_error={}, *args, **kwargs):
     '''
     plots mean value of the NetworkSet with +- uncertainty bounds
     in an Network's attribute. This is designed to represent
@@ -1513,7 +1573,7 @@ def plot_uncertainty_bounds_component(self,attribute,m=None,n=None,\
                     of error bars
             ax: Axes to plot on
             ppf: post processing function. a function applied to the
-                    upper and low
+                    upper and lower bounds
             *args,**kwargs: passed to Network.plot_s_re command used
                     to plot mean response
             kwargs_error: dictionary of kwargs to pass to the fill_between
@@ -1541,55 +1601,59 @@ def plot_uncertainty_bounds_component(self,attribute,m=None,n=None,\
     for m in M:
         for n in N:
 
+            plot_attribute = attribute
+
             ax = plb.gca()
 
             ntwk_mean = self.__getattribute__('mean_'+attribute)
             ntwk_std = self.__getattribute__('std_'+attribute)
             ntwk_std.s = n_deviations * ntwk_std.s
 
-            upper_bound = (ntwk_mean.s[:,m,n] +ntwk_std.s[:,m,n]).squeeze()
-            lower_bound = (ntwk_mean.s[:,m,n] -ntwk_std.s[:,m,n]).squeeze()
-
+            upper_bound = (ntwk_mean.s[:, m, n] + ntwk_std.s[:, m, n]).squeeze()
+            lower_bound = (ntwk_mean.s[:, m, n] - ntwk_std.s[:, m, n]).squeeze()
 
             if ppf is not None:
                 if type =='bar':
-                    warnings.warn('the \'ppf\' options don\'t work correctly with the bar-type error plots')
+                    raise NotImplementedError('the \'ppf\' options don\'t work correctly with the bar-type error plots')
                 ntwk_mean.s = ppf(ntwk_mean.s)
                 upper_bound = ppf(upper_bound)
                 lower_bound = ppf(lower_bound)
                 lower_bound[npy.isnan(lower_bound)]=min(lower_bound)
-                if ppf in [mf.magnitude_2_db, mf.mag_2_db]: # quickfix of wrong ylabels due to usage of ppf for *_db plots
+                if ppf in [mf.magnitude_2_db, mf.mag_2_db]:  # quickfix of wrong ylabels due to usage of ppf for *_db plots
                     if attribute is 's_mag':
-                        attribute = 's_db'
+                        plot_attribute = 's_db'
                     elif attribute is 's_time_mag':
-                        attribute = 's_time_db'
+                        plot_attribute = 's_time_db'
 
             if type == 'shade':
-                ntwk_mean.plot_s_re(ax=ax,m=m,n=n,*args, **kwargs)
+                ntwk_mean.plot_s_re(ax=ax, m=m, n=n, *args, **kwargs)
                 if color_error is None:
                     color_error = ax.get_lines()[-1].get_color()
-                ax.fill_between(ntwk_mean.frequency.f_scaled, \
-                        lower_bound,upper_bound, alpha=alpha, color=color_error,
-                        **kwargs_error)
-                #ax.plot(ntwk_mean.frequency.f_scaled,ntwk_mean.s[:,m,n],*args,**kwargs)
-            elif type =='bar':
-                ntwk_mean.plot_s_re(ax=ax,m=m,n=n,*args, **kwargs)
+                ax.fill_between(ntwk_mean.frequency.f,
+                                lower_bound, upper_bound, alpha=alpha, color=color_error,
+                                **kwargs_error)
+                # ax.plot(ntwk_mean.frequency.f_scaled, ntwk_mean.s[:,m,n],*args,**kwargs)
+
+            elif type == 'bar':
+                ntwk_mean.plot_s_re(ax=ax, m=m, n=n, *args, **kwargs)
                 if color_error is None:
                     color_error = ax.get_lines()[-1].get_color()
-                ax.errorbar(ntwk_mean.frequency.f_scaled[::markevery_error],\
-                        ntwk_mean.s_re[:,m,n].squeeze()[::markevery_error], \
-                        yerr=ntwk_std.s_mag[:,m,n].squeeze()[::markevery_error],\
-                        color=color_error,**kwargs_error)
+                ax.errorbar(ntwk_mean.frequency.f[::markevery_error],
+                            ntwk_mean.s_re[:, m, n].squeeze()[::markevery_error],
+                            yerr=ntwk_std.s_mag[:, m, n].squeeze()[::markevery_error],
+                            color=color_error, **kwargs_error)
 
             else:
                 raise(ValueError('incorrect plot type'))
 
-            ax.set_ylabel(Y_LABEL_DICT.get(attribute[2:],''))  # use only the function of the attribute
+            ax.set_ylabel(Y_LABEL_DICT.get(plot_attribute[2:],''))  # use only the function of the attribute
+            scale_frequency_ticks(ax, ntwk_mean.frequency.unit)
             ax.axis('tight')
 
-def plot_minmax_bounds_component(self,attribute,m=0,n=0,\
-        type='shade', alpha=.3, color_error =None,markevery_error=20,
-        ax=None,ppf=None,kwargs_error={},*args,**kwargs):
+
+def plot_minmax_bounds_component(self, attribute, m=0, n=0,
+                                 type='shade', alpha=.3, color_error=None, markevery_error=20,
+                                 ax=None, ppf=None, kwargs_error={}, *args, **kwargs):
     '''
     plots mean value of the NetworkSet with +- uncertainty bounds
     in an Network's attribute. This is designed to represent
@@ -1629,19 +1693,17 @@ def plot_minmax_bounds_component(self,attribute,m=0,n=0,\
 
     '''
 
-    ax = plb.gca()
+    if ax is None:
+        ax = plb.gca()
 
     ntwk_mean = self.__getattribute__('mean_'+attribute)
 
-
     lower_bound = self.__getattribute__('min_'+attribute).s_re[:,m,n].squeeze()
     upper_bound = self.__getattribute__('max_'+attribute).s_re[:,m,n].squeeze()
 
-
-
     if ppf is not None:
         if type =='bar':
-            warnings.warn('the \'ppf\' options don\'t work correctly with the bar-type error plots')
+            raise NotImplementedError('the \'ppf\' options don\'t work correctly with the bar-type error plots')
         ntwk_mean.s = ppf(ntwk_mean.s)
         upper_bound = ppf(upper_bound)
         lower_bound = ppf(lower_bound)
@@ -1656,27 +1718,28 @@ def plot_minmax_bounds_component(self,attribute,m=0,n=0,\
         ntwk_mean.plot_s_re(ax=ax,m=m,n=n,*args, **kwargs)
         if color_error is None:
             color_error = ax.get_lines()[-1].get_color()
-        ax.fill_between(ntwk_mean.frequency.f_scaled, \
-                lower_bound,upper_bound, alpha=alpha, color=color_error,
-                **kwargs_error)
+        ax.fill_between(ntwk_mean.frequency.f,
+                        lower_bound, upper_bound, alpha=alpha, color=color_error,
+                        **kwargs_error)
         #ax.plot(ntwk_mean.frequency.f_scaled,ntwk_mean.s[:,m,n],*args,**kwargs)
     elif type =='bar':
         raise (NotImplementedError)
-        ntwk_mean.plot_s_re(ax=ax,m=m,n=n,*args, **kwargs)
+        ntwk_mean.plot_s_re(ax=ax, m=m, n=n, *args, **kwargs)
         if color_error is None:
             color_error = ax.get_lines()[-1].get_color()
-        ax.errorbar(ntwk_mean.frequency.f_scaled[::markevery_error],\
-                ntwk_mean.s_re[:,m,n].squeeze()[::markevery_error], \
-                yerr=ntwk_std.s_mag[:,m,n].squeeze()[::markevery_error],\
-                color=color_error,**kwargs_error)
+        ax.errorbar(ntwk_mean.frequency.f[::markevery_error],
+                    ntwk_mean.s_re[:,m,n].squeeze()[::markevery_error],
+                    yerr=ntwk_std.s_mag[:,m,n].squeeze()[::markevery_error],
+                    color=color_error,**kwargs_error)
 
     else:
         raise(ValueError('incorrect plot type'))
 
-    ax.set_ylabel(Y_LABEL_DICT.get(attribute[2:],''))  # use only the function of the attribute
+    ax.set_ylabel(Y_LABEL_DICT.get(attribute[2:], ''))  # use only the function of the attribute
+    scale_frequency_ticks(ax, ntwk_mean.frequency.unit)
     ax.axis('tight')
 
-def plot_uncertainty_bounds_s_db(self,*args, **kwargs):
+def plot_uncertainty_bounds_s_db(self, *args, **kwargs):
     '''
     this just calls
             plot_uncertainty_bounds(attribute= 's_mag','ppf':mf.magnitude_2_db*args,**kwargs)
@@ -1826,8 +1889,6 @@ def signature(self, m=0, n=0, component='s_mag',
     of each Network in the  NetworkSet, vs frequency.
 
 
-
-
     Parameters
     ------------
     m : int
